MethodChannelAlipayPayment class

Inheritance
Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

auth({required String authInfo, String? urlScheme, String? universalLink, bool showPayLoading = true}) Future<void>
override
authAndWait({required String authInfo, String? urlScheme, String? universalLink, bool showPayLoading = true, Duration timeout = const Duration(minutes: 5)}) Future<AlipayResult>

Available on AlipayPaymentPlatform, provided by the AlipayPaymentWait extension

authResp() Stream<AlipayResult>
override
dispose() → void
override
getPlatformVersion() Future<String?>
override
isAlipayInstalled() Future<bool>
检测是否已安装支付宝客户端
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pay({required String orderInfo, String? urlScheme, String? universalLink, bool showPayLoading = true, AlipayEnvironment? payEnv, bool dynamicLaunch = false}) Future<void>
override
payAndWait({required String orderInfo, String? urlScheme, String? universalLink, bool showPayLoading = true, AlipayEnvironment? payEnv, bool dynamicLaunch = false, Duration timeout = const Duration(minutes: 5)}) Future<AlipayResult>

Available on AlipayPaymentPlatform, provided by the AlipayPaymentWait extension

payResp() Stream<AlipayResult>
override
setEnvironment(AlipayEnvironment environment) Future<void>
override
toString() String
A string representation of this object.
inherited
unsafeAuth({required String appId, required String pid, required String targetId, String authType = AlipaySign.authTypeAuthAccount, String signType = AlipaySign.signTypeRsa2, required String privateKey, bool isShowLoading = true, String? urlScheme, String? universalLink}) Future<void>

Available on AlipayPaymentPlatform, provided by the AlipayPaymentUnsafe extension

客户端签名授权
unsafePay({required Map<String, dynamic> orderInfo, String signType = AlipaySign.signTypeRsa2, required String privateKey, bool isShowLoading = true, String? urlScheme, String? universalLink, AlipayEnvironment? payEnv, bool dynamicLaunch = false}) Future<void>

Available on AlipayPaymentPlatform, provided by the AlipayPaymentUnsafe extension

客户端签名支付

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

channelName → const String